@@ -17,7 +17,7 @@
 # housekeeping
 ########################################################################
 
-package FindBin::libs;
+package FindBin::libs   v2.12.01;
 
 use v5.14;
 use strict;
@@ -75,9 +75,6 @@ BEGIN
 # package variables 
 ########################################################################
 
-our $VERSION    = '2.11';
-$VERSION = eval $VERSION;
-
 my %defaultz = 
 (
     base    => 'lib',
@@ -333,12 +330,7 @@ sub import
 {
     &$handle_args;
 
-    my @libz = $find_libs->()
-    or do
-    {
-        say 'No libs found';
-        return
-    };
+    my @libz = $find_libs->();
 
     # HAK ALERT: the regex does nothing for security,
     # just dodges -T. putting this down here instead
@@ -360,6 +352,10 @@ sub import
 
     if( $argz{ export } )
     {
+        # this has to run in order to install variables that
+        # the caller is expecting to exist at runtime -- even
+        # if they are empty/undef at the end of it.
+
         my $ref     = qualify_to_ref $argz{ export }, $caller;
 
         if( $verbose )
@@ -374,7 +370,11 @@ sub import
 
         if( $argz{ scalar } )
         {
-            *$ref = \$libz[0]
+            *$ref 
+            = @libz
+            ? \$libz[0]
+            : \( my $a = '' )
+            ;
         }
         elsif
         (
@@ -393,29 +393,32 @@ sub import
 
     # no 'else', these are not exclusive
 
-    if( defined $argz{ p5lib } )
+    if( @libz )
     {
-        # stuff the lib's found at the front of $ENV{ PERL5LIB }
-        # yes, virginia, substr is an lvalue -- and saner than
-        # dealing with \Q and a regex on arbitrary paths.
+        if( defined $argz{ p5lib } )
+        {
+            # stuff the lib's found at the front of $ENV{ PERL5LIB }
+            # yes, virginia, substr is an lvalue -- and saner than
+            # dealing with \Q and a regex on arbitrary paths.
 
-        ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, '';
+            ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, '';
 
-        print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
-        if $verbose;
-    }
+            print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
+            if $verbose;
+        }
 
-    if( $argz{ use } )
-    {
-        # this obviously won't work if lib ever depends 
-        # on the caller's package.
-        #
-        # it does avoids issues with -T blowing up on the
-        # old eval technique.
+        if( $argz{ use } )
+        {
+            # this obviously won't work if lib ever depends 
+            # on the caller's package.
+            #
+            # it does avoids issues with -T blowing up on the
+            # old eval technique.
 
-        require lib;
+            require lib;
 
-        lib->import( @libz );
+            lib->import( @libz );
+        }
     }
 
     0
@@ -1088,5 +1091,10 @@ Steven Lembark, Workhorse Computing <lembark@wrkhors.com>
 =head1 COPYRIGHT
 
 Copyright (C) 2003-2014, Steven Lembark, Workhorse Computing.
-This code is released under the same terms as Perl-5.20
+This code is released under the same terms as Perl-5.24
+or any later version of Perl.
+
+=head1 LICENSE
+
+This code is released under the same terms as Perl-5.24
 or any later version of Perl.
